@@ -16,7 +16,7 @@ p0 <- function(...) paste(..., sep="")
     npq <- as.integer(nar + nma)
     npq1 <- npq + 1L # integer, too
     stopifnot(length(di <- dim(hess)) == 2, di == c(npq1, npq1))
-    fdc <- .C("fdcov", ## --> ../src/fdhess.c
+    fdc <- .C(fdcov, ## --> ../src/fdhess.c
 	      x,
 	      d,
 	      h = as.double(if(missing(h)) -1 else h),
@@ -25,8 +25,7 @@ p0 <- function(...) paste(..., sep="")
 	      cor = hess, npq1,
 	      se = double(npq1),
 	      fdf.work,
-	      info = integer(1),
-	      PACKAGE = "fracdiff")[c("h","hd", "cov","cor", "se", "info")]
+	      info = integer(1))[c("h","hd", "cov","cor", "se", "info")]
 
     f.msg <-
 	if(fdc$info) {
@@ -57,7 +56,7 @@ p0 <- function(...) paste(..., sep="")
 
 fracdiff <- function(x, nar = 0, nma = 0,
                      ar = rep(NA, max(nar, 1)), ma = rep(NA, max(nma, 1)),
-                     dtol = NULL, drange = c(0, 0.5), h, M = 100)
+                     dtol = NULL, drange = c(0, 0.5), h, M = 100, trace = 0)
 {
     ## #########################################################################
     ##
@@ -101,7 +100,7 @@ fracdiff <- function(x, nar = 0, nma = 0,
     x <- as.double(x)
 
     ## this also initializes "common blocks" that are used in .C(.) calls :
-    fdf <- .C("fracdf",
+    fdf <- .C(fracdf,
 	      x,
 	      n,
 	      as.integer(M),
@@ -109,19 +108,18 @@ fracdiff <- function(x, nar = 0, nma = 0,
 	      as.integer(nma),
 	      dtol = as.double(dtol),
 	      drange = as.double(drange),
-	      hood = double(1),
+	      hood.etc = double(3),
 	      d = double(1),
 	      ar = as.double(ar),
 	      ma = as.double(ma),
 	      w = double(lenw),
 	      lenw = lenw,
 	      iw = integer(npq), ## <<< new int-work array
-	      info = integer(1),
+	      info = as.integer(trace > 0),## <- "verbose" [input]
 	      .Machine$double.xmin,
 	      .Machine$double.xmax,
 	      .Machine$double.neg.eps,
-	      .Machine$double.eps,
-	      PACKAGE = "fracdiff")[c("dtol","drange","hood",
+	      .Machine$double.eps)[c("dtol","drange","hood.etc",
 	      "d", "ar", "ma", "w", "lenw", "info")]
 
     fd.msg <-
@@ -144,11 +142,10 @@ fracdiff <- function(x, nar = 0, nma = 0,
     if(nar == 0) fdf$ar <- numeric(0)
     if(nma == 0) fdf$ma <- numeric(0)
 
-    hess <- .C("fdhpq",
+    hess <- .C(fdhpq,
                hess = matrix(double(1), npq1, npq1),
                npq1,
-               fdf$w,
-               PACKAGE = "fracdiff")$hess
+               fdf$w)$hess
 
     ## NOTA BENE: The above  hess[.,.]  is further "transformed",
     ##            well, added to  and inverted  in fdcov :
@@ -163,10 +160,14 @@ fracdiff <- function(x, nar = 0, nma = 0,
     hess[1, ] <- fdc$hd
     hess[row(hess) > col(hess)] <- hess[row(hess) < col(hess)]
 
-    structure(list(log.likelihood = fdf$hood, n = n,
+    hstat <- fdf[["hood.etc"]]
+    var.WN <- hstat[3]
+    structure(list(log.likelihood = hstat[1],
+                   n = n,
 		   msg = c(fracdf = fd.msg, fdcov = fdc$msg),
 		   d = fdf$d, ar = fdf$ar, ma = fdf$ma,
 		   covariance.dpq = fdc$covariance.dpq,
+		   fnormMin = hstat[2], sigma = sqrt(var.WN),
 		   stderror.dpq	  = if(fdc$se.ok) fdc$stderror.dpq, # else NULL
 		   correlation.dpq= if(fdc$se.ok) fdc$correlation.dpq,
 		   h = fdc$h, d.tol = fdf$dtol, M = M, hessian.dpq = hess,
@@ -192,7 +193,7 @@ fracdiff.var <- function(x, fracdiff.out, h)
                  3 * n + (n + 6) * npq + npq %/% 2 + 1,
                  (3 + 2 * npq1) * npq1 + 1)
     ## Initialize
-    .C("fdcom",
+    .C(fdcom,
        n,
        as.integer(M),
        (p),
@@ -201,24 +202,22 @@ fracdiff.var <- function(x, fracdiff.out, h)
        .Machine$double.xmin,
        .Machine$double.xmax,
        .Machine$double.neg.eps,
-       .Machine$double.eps,
-       PACKAGE = "fracdiff")
+       .Machine$double.eps)
     ## Re compute Covariance Matrix:
-    fdc <- .C("fdcov",
-               as.double(x),
-               as.double(fracdiff.out$d),
-               h = as.double(h),
-               hd = double(npq1),
-               cov = as.double(fracdiff.out$hessian.dpq),
-               as.integer(npq1),
-               cor = as.double(fracdiff.out$hessian.dpq),
-               as.integer(npq1),
-               se = double(npq1),
-               as.double(c(fracdiff.out$ma,
-                           fracdiff.out$ar,
-                           rep(0, lwork))),
-               info = integer(1),
-               PACKAGE = "fracdiff")
+    fdc <- .C(fdcov,
+              as.double(x),
+              as.double(fracdiff.out$d),
+              h = as.double(h),
+              hd = double(npq1),
+              cov = as.double(fracdiff.out$hessian.dpq),
+              as.integer(npq1),
+              cor = as.double(fracdiff.out$hessian.dpq),
+              as.integer(npq1),
+              se = double(npq1),
+              as.double(c(fracdiff.out$ma,
+                          fracdiff.out$ar,
+                          rep(0, lwork))),
+              info = integer(1))
 ## FIXME: should be *automatically* same messages as inside fracdiff() above!
     fracdiff.out$msg <-
         if(fdc$info) {
@@ -266,7 +265,7 @@ fracdiff.sim <- function(n, ar = NULL, ma = NULL, d, rand.gen = rnorm,
     if(length(innov) < n+q) stop("'innov' must have length >= n + q")
     y <- c(rand.gen(n.start, ...), innov[1:(n+q)])
     stopifnot(is.double(y), length(y) == n + q + n.start)
-    y <- .C("fdsim",
+    y <- .C(fdsim,
             as.integer(n + n.start),
             (p),
             (q),
@@ -279,7 +278,6 @@ fracdiff.sim <- function(n, ar = NULL, ma = NULL, d, rand.gen = rnorm,
             .Machine$double.xmin,
             .Machine$double.xmax,
             .Machine$double.neg.eps,
-            .Machine$double.eps,
-            PACKAGE = "fracdiff")[["s"]][n.start + 1:n]
+            .Machine$double.eps)[["s"]][n.start + 1:n]
     list(series = y, ar = ar, ma = ma, d = d, mu = mu, n.start = n.start)
 }
